@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QAction>
 #include <QApplication>
-#include <QBitmap>
 #include <QCheckBox>
 #include <QEvent>
 #include <QGridLayout>
@@ -52,6 +51,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gwenviewconfig.h>
 #include <lib/imagemetainfomodel.h>
 #include <lib/thumbnailview/thumbnailbarview.h>
+#include <lib/shadowfilter.h>
 #include <lib/slideshow.h>
 
 namespace Gwenview
@@ -90,6 +90,11 @@ public:
         mLayout->addSpacing(KDialog::spacingHint());
     }
 
+    void addStretch()
+    {
+        mLayout->addStretch();
+    }
+
     void setDirection(QBoxLayout::Direction direction)
     {
         mLayout->setDirection(direction);
@@ -120,6 +125,9 @@ struct FullScreenContentPrivate
     FullScreenToolBar* mRightToolBar;
     ThumbnailBarView* mThumbnailBar;
     QLabel* mInformationLabel;
+    ShadowFilter* mToolBarShadow;
+    ShadowFilter* mRightToolBarShadow;
+    ShadowFilter* mInformationLabelShadow;
     Document::Ptr mCurrentDocument;
     QPointer<ImageMetaInfoDialog> mImageMetaInfoDialog;
     QPointer<FullScreenConfigWidget> mConfigWidget;
@@ -163,8 +171,6 @@ struct FullScreenContentPrivate
         delete mContent->layout();
 
         if (GwenviewConfig::showFullScreenThumbnails()) {
-            mInformationLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
-
             mRightToolBar->setDirection(QBoxLayout::TopToBottom);
 
             QHBoxLayout* layout = new QHBoxLayout(mContent);
@@ -176,7 +182,6 @@ struct FullScreenContentPrivate
             vLayout = new QVBoxLayout;
             vLayout->addWidget(mToolBar);
             vLayout->addWidget(mInformationLabel);
-            vLayout->addStretch();
             layout->addLayout(vLayout);
             // Second column
             layout->addSpacing(2);
@@ -185,14 +190,26 @@ struct FullScreenContentPrivate
             // Third column
             vLayout = new QVBoxLayout;
             vLayout->addWidget(mRightToolBar);
-            vLayout->addStretch();
             layout->addLayout(vLayout);
 
             mThumbnailBar->setFixedHeight(GwenviewConfig::fullScreenBarHeight());
             mAutoHideContainer->setFixedHeight(GwenviewConfig::fullScreenBarHeight());
-        } else {
-            mInformationLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 
+            // Shadows
+            mToolBarShadow->reset();
+            mToolBarShadow->setShadow(ShadowFilter::RightEdge, QColor(0, 0, 0, 64));
+            mToolBarShadow->setShadow(ShadowFilter::BottomEdge, QColor(255, 255, 255, 8));
+
+            mInformationLabelShadow->reset();
+            mInformationLabelShadow->setShadow(ShadowFilter::LeftEdge, QColor(0, 0, 0, 64));
+            mInformationLabelShadow->setShadow(ShadowFilter::TopEdge, QColor(0, 0, 0, 64));
+            mInformationLabelShadow->setShadow(ShadowFilter::RightEdge, QColor(0, 0, 0, 128));
+            mInformationLabelShadow->setShadow(ShadowFilter::BottomEdge, QColor(255, 255, 255, 8));
+
+            mRightToolBarShadow->reset();
+            mRightToolBarShadow->setShadow(ShadowFilter::LeftEdge, QColor(0, 0, 0, 64));
+            mRightToolBarShadow->setShadow(ShadowFilter::BottomEdge, QColor(255, 255, 255, 8));
+        } else {
             mRightToolBar->setDirection(QBoxLayout::RightToLeft);
 
             QHBoxLayout* layout = new QHBoxLayout(mContent);
@@ -203,6 +220,16 @@ struct FullScreenContentPrivate
             layout->addWidget(mRightToolBar);
 
             mAutoHideContainer->setFixedHeight(mContent->sizeHint().height());
+
+            // Shadows
+            mToolBarShadow->reset();
+
+            mInformationLabelShadow->reset();
+            mInformationLabelShadow->setShadow(ShadowFilter::LeftEdge, QColor(0, 0, 0, 64));
+            mInformationLabelShadow->setShadow(ShadowFilter::RightEdge, QColor(0, 0, 0, 32));
+
+            mRightToolBarShadow->reset();
+            mRightToolBarShadow->setShadow(ShadowFilter::LeftEdge, QColor(255, 255, 255, 8));
         }
     }
 };
@@ -240,7 +267,6 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     d->mContent->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     d->mContent->setAutoFillBackground(true);
     EventWatcher::install(d->mContent, QEvent::Show, this, SLOT(updateCurrentUrlWidgets()));
-    EventWatcher::install(d->mContent, QEvent::Resize, this, SLOT(updateWidgetMask()));
     EventWatcher::install(d->mContent, QEvent::PaletteChange, this, SLOT(slotPaletteChanged()));
     layout->addWidget(d->mContent);
 
@@ -260,13 +286,15 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     addAction("rotate_left");
     addAction("rotate_right");
     #undef addAction
+    d->mToolBarShadow = new ShadowFilter(d->mToolBar);
 
     // mInformationLabel
     d->mInformationLabel = new QLabel;
     d->mInformationLabel->setWordWrap(true);
     d->mInformationLabel->setContentsMargins(6, 0, 6, 0);
-    d->mInformationLabel->setFixedHeight(d->mToolBar->sizeHint().height());
+    d->mInformationLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
     d->mInformationLabel->setAutoFillBackground(true);
+    d->mInformationLabelShadow = new ShadowFilter(d->mInformationLabel);
 
     // Thumbnail bar
     d->mThumbnailBar = new ThumbnailBarView(d->mContent);
@@ -279,6 +307,9 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     d->mRightToolBar = new FullScreenToolBar(d->mContent);
     d->mRightToolBar->addAction(d->mActionCollection->action("leave_fullscreen"));
     d->mRightToolBar->addAction(d->mOptionsAction);
+    d->mRightToolBar->addStretch();
+    d->mRightToolBar->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    d->mRightToolBarShadow = new ShadowFilter(d->mRightToolBar);
 
     d->updateLayout();
 
@@ -336,41 +367,6 @@ void FullScreenContent::updateCurrentUrlWidgets()
     updateMetaInfoDialog();
 }
 
-void FullScreenContent::updateWidgetMask()
-{
-    if (!GwenviewConfig::showFullScreenThumbnails()) {
-        d->mContent->clearMask();
-        return;
-    }
-
-    QSize size = d->mContent->size();
-    QBitmap mask(size);
-    mask.clear();
-    {
-        QPainter painter(&mask);
-        // Paint thumbnailbar + thin borders
-        QRect rect = d->mThumbnailBar->geometry().adjusted(-2, 0, 2, 0);
-        painter.fillRect(rect, Qt::color1);
-
-        // "Round the corners of the thin borders. We can't use compositing
-        // yet, so it's pixel-art for now :/
-        painter.setPen(Qt::color0);
-        int x = rect.left(), y = rect.bottom();
-        painter.drawPoint(x, y);
-        painter.drawPoint(x, y - 1);
-        painter.drawPoint(x + 1, y);
-        x = rect.right();
-        painter.drawPoint(x, y);
-        painter.drawPoint(x, y - 1);
-        painter.drawPoint(x - 1, y);
-
-        // Paint toolbars + label as one big rectangle, this way we repaint
-        // rounded corners if necessary
-        painter.fillRect(0, 0, size.width(), d->mRightToolBar->height(), Qt::color1);
-    }
-    d->mContent->setMask(mask);
-}
-
 void FullScreenContent::showImageMetaInfoDialog()
 {
     if (!d->mImageMetaInfoDialog) {
