@@ -36,9 +36,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KMenu>
 #include <KMessageBox>
 #include <KToggleAction>
+#include <KActivities/ResourceInstance>
 
 // Local
 #include "fileoperations.h"
+#include <gvcore.h>
 #include "splitter.h"
 #include <lib/document/document.h>
 #include <lib/documentview/abstractdocumentviewadapter.h>
@@ -133,6 +135,7 @@ struct ViewMainPagePrivate
     ViewMainPage* q;
     SlideShow* mSlideShow;
     KActionCollection* mActionCollection;
+    GvCore* mGvCore;
     QSplitter *mThumbnailSplitter;
     QWidget* mAdapterContainer;
     DocumentViewController* mDocumentViewController;
@@ -149,6 +152,11 @@ struct ViewMainPagePrivate
     KToggleAction* mSynchronizeAction;
     QCheckBox* mSynchronizeCheckBox;
 
+    // Activity Resource events reporting needs to be above KPart,
+    // in the shell itself, to avoid problems with other MDI applications
+    // that use this KPart
+    QHash<DocumentView*, KActivities::ResourceInstance*> mActivityResources;
+
     bool mFullScreenMode;
     QPalette mNormalPalette;
     bool mCompareMode;
@@ -270,6 +278,7 @@ struct ViewMainPagePrivate
     {
         mDocumentViewContainer->deleteView(view);
         mDocumentViews.removeOne(view);
+        mActivityResources.remove(view);
     }
 
     void setupToolContainer()
@@ -302,6 +311,7 @@ struct ViewMainPagePrivate
         Qt::Orientation orientation = GwenviewConfig::thumbnailBarOrientation();
         mThumbnailSplitter = new Splitter(orientation == Qt::Horizontal ? Qt::Vertical : Qt::Horizontal, q);
         mThumbnailBar->setOrientation(orientation);
+        mThumbnailBar->setThumbnailAspectRatio(GwenviewConfig::thumbnailAspectRatio());
         mThumbnailBar->setRowCount(GwenviewConfig::thumbnailBarRowCount());
         mThumbnailSplitter->addWidget(mAdapterContainer);
         mThumbnailSplitter->addWidget(mThumbnailBar);
@@ -343,6 +353,14 @@ struct ViewMainPagePrivate
             return;
         }
         mThumbnailBar->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Current);
+
+        if (mActivityResources.contains(oldView)) {
+            mActivityResources[oldView]->notifyFocusedOut();
+        }
+
+        if (mActivityResources.contains(view)) {
+            mActivityResources[view]->notifyFocusedIn();
+        }
     }
 
     QModelIndex indexForView(DocumentView* view) const
@@ -357,15 +375,22 @@ struct ViewMainPagePrivate
         SortedDirModel* model = static_cast<SortedDirModel*>(mThumbnailBar->model());
         return model->indexForUrl(url);
     }
+
+    void applyPalette(bool fullScreenMode)
+    {
+        mDocumentViewContainer->setPalette(mGvCore->palette(fullScreenMode ? GvCore::FullScreenViewPalette : GvCore::NormalViewPalette));
+        setupThumbnailBarStyleSheet();
+    }
 };
 
-ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollection* actionCollection)
+ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollection* actionCollection, GvCore* gvCore)
 : QWidget(parent)
 , d(new ViewMainPagePrivate)
 {
     d->q = this;
     d->mSlideShow = slideShow;
     d->mActionCollection = actionCollection;
+    d->mGvCore = gvCore;
     d->mFullScreenMode = false;
     d->mCompareMode = false;
     d->mThumbnailBarVisibleBeforeFullScreen = false;
@@ -415,6 +440,8 @@ ViewMainPage::~ViewMainPage()
 
 void ViewMainPage::loadConfig()
 {
+    d->applyPalette(false /* fullScreenMode */);
+
     // FIXME: Not symetric with saveConfig(). Check if it matters.
     Q_FOREACH(DocumentView * view, d->mDocumentViews) {
         view->loadAdapterConfig();
@@ -481,15 +508,12 @@ void ViewMainPage::setFullScreenMode(bool fullScreenMode)
         if (d->mThumbnailBarVisibleBeforeFullScreen) {
             d->mToggleThumbnailBarAction->trigger();
         }
-        QPalette pal = QApplication::palette();
-        pal.setColor(QPalette::Base, Qt::black);
-        d->mDocumentViewContainer->setPalette(pal);
     } else {
         if (d->mThumbnailBarVisibleBeforeFullScreen) {
             d->mToggleThumbnailBarAction->trigger();
         }
-        d->mDocumentViewContainer->setPalette(d->mNormalPalette);
     }
+    d->applyPalette(fullScreenMode);
     d->mToggleThumbnailBarAction->setEnabled(!fullScreenMode);
 }
 
@@ -582,13 +606,6 @@ DocumentView* ViewMainPage::documentView() const
     return d->currentView();
 }
 
-void ViewMainPage::setNormalPalette(const QPalette& palette)
-{
-    d->mNormalPalette = palette;
-    d->mDocumentViewContainer->setPalette(palette);
-    d->setupThumbnailBarStyleSheet();
-}
-
 void ViewMainPage::openUrl(const KUrl& url)
 {
     openUrls(KUrl::List() << url, url);
@@ -661,6 +678,18 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
         } else {
             view->setCurrent(false);
         }
+
+        if (!d->mActivityResources.contains(view)) {
+            d->mActivityResources[view] = new KActivities::ResourceInstance(window()->winId(), view);
+        }
+
+        d->mActivityResources[view]->setUri(view->url());
+
+        if (view->url() == currentUrl) {
+            d->mActivityResources[view]->notifyFocusedIn();
+        } else {
+            d->mActivityResources[view]->notifyFocusedOut();
+        }
     }
 
     d->mSynchronizeCheckBox->setVisible(d->mCompareMode);
