@@ -22,18 +22,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "thumbnailpage.moc"
 
 // Qt
-#include <QMenu>
 #include <QPushButton>
 #include <QTreeView>
-#include <QWidgetAction>
 
 // KDE
 #include <KDebug>
+#include <KDialog>
 #include <KDirLister>
 #include <KDirModel>
-#include <KDirSelectDialog>
 #include <KIconLoader>
 #include <KIO/NetAccess>
+#include <kmodelindexproxymapper.h>
 
 // Local
 #include <lib/archiveutils.h>
@@ -81,7 +80,6 @@ inline KFileItem itemForIndex(const QModelIndex& index)
 struct ThumbnailPagePrivate : public Ui_ThumbnailPage
 {
     ThumbnailPage* q;
-    QMenu* mSrcUrlMenu;
     SerializedUrlMap mUrlMap;
 
     ThumbnailPagePrivate()
@@ -89,8 +87,11 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
         mUrlMap.setConfigGroup(KConfigGroup(KGlobal::config(), URL_FOR_BASE_URL_GROUP));
     }
 
+    KIcon mSrcBaseIcon;
+    QString mSrcBaseName;
     KUrl mSrcBaseUrl;
     KUrl mSrcUrl;
+    KModelIndexProxyMapper* mSrcUrlModelProxyMapper;
 
     RecursiveDirModel* mRecursiveDirModel;
     QAbstractItemModel* mFinalModel;
@@ -136,11 +137,13 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
         mDstIconLabel->setPixmap(KIconLoader::global()->loadIcon("computer", group, size));
     }
 
-    void setupSrcUrlButton()
+    void setupSrcUrlWidgets()
     {
-        mSrcUrlMenu = new QMenu(q);
-        QObject::connect(mSrcUrlMenu, SIGNAL(aboutToShow()), q, SLOT(initSrcUrlMenu()));
-        mSrcUrlButton->setMenu(mSrcUrlMenu);
+        mSrcUrlModelProxyMapper = 0;
+        QObject::connect(mSrcUrlButton, SIGNAL(clicked()), q, SLOT(setupSrcUrlTreeView()));
+        QObject::connect(mSrcUrlButton, SIGNAL(clicked()), q, SLOT(toggleSrcUrlTreeView()));
+        mSrcUrlTreeView->hide();
+        mSrcUrlTreeView->parentWidget()->layout()->setSpacing(0);
     }
 
     void setupDstUrlRequester()
@@ -233,7 +236,7 @@ ThumbnailPage::ThumbnailPage()
     d->setupUi(this);
     d->setupIcons();
     d->setupDirModel();
-    d->setupSrcUrlButton();
+    d->setupSrcUrlWidgets();
     d->setupDstUrlRequester();
     d->setupThumbnailView();
     d->setupButtonBox();
@@ -245,9 +248,16 @@ ThumbnailPage::~ThumbnailPage()
     delete d;
 }
 
-void ThumbnailPage::setSourceUrl(const KUrl& srcBaseUrl)
+void ThumbnailPage::setSourceUrl(const KUrl& srcBaseUrl, const QString& iconName, const QString& name)
 {
+    d->mSrcBaseIcon = KIcon(iconName);
+    d->mSrcBaseName = name;
+
+    const int size = KIconLoader::SizeHuge;
+    d->mSrcIconLabel->setPixmap(d->mSrcBaseIcon.pixmap(size));
+
     d->mSrcBaseUrl = srcBaseUrl;
+    d->mSrcBaseUrl.adjustPath(KUrl::AddTrailingSlash);
     KUrl url = d->urlForBaseUrl();
 
     if (url.isValid()) {
@@ -268,9 +278,15 @@ void ThumbnailPage::slotDocumentDirFinderDone(const KUrl& url, DocumentDirFinder
 
 void ThumbnailPage::openUrl(const KUrl& url)
 {
-    kWarning() << url;
     d->mSrcUrl = url;
-    d->mSrcUrlButton->setText(url.pathOrUrl());
+    QString path = KUrl::relativeUrl(d->mSrcBaseUrl, d->mSrcUrl);
+    QString text;
+    if (path.isEmpty() || path == "./") {
+        text = d->mSrcBaseName;
+    } else {
+        text = QString("%1/%2").arg(d->mSrcBaseName).arg(path);
+    }
+    d->mSrcUrlButton->setText(text);
     d->mRecursiveDirModel->setUrl(url);
 }
 
@@ -329,36 +345,100 @@ void ThumbnailPage::showConfigDialog()
     dialog.exec();
 }
 
-void ThumbnailPage::initSrcUrlMenu()
+/**
+ * This model allows only the url passed in the constructor to appear at the root
+ * level. This makes it possible to select the url, but not its siblings.
+ * It also provides custom role values for the root item.
+ */
+class OnlyBaseUrlProxyModel : public QSortFilterProxyModel
 {
-    if (!d->mSrcUrlMenu->isEmpty()) {
+public:
+    OnlyBaseUrlProxyModel(const KUrl& url, const KIcon& icon, const QString& name, QObject* parent)
+    : QSortFilterProxyModel(parent)
+    , mUrl(url)
+    , mIcon(icon)
+    , mName(name)
+    {}
+
+    bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const // reimp
+    {
+        if (sourceParent.isValid()) {
+            return true;
+        }
+        QModelIndex index = sourceModel()->index(sourceRow, 0);
+        KFileItem item = itemForIndex(index);
+        return item.url().equals(mUrl, KUrl::CompareWithoutTrailingSlash);
+    }
+
+    QVariant data(const QModelIndex& index, int role) const // reimp
+    {
+        if (index.parent().isValid()) {
+            return QSortFilterProxyModel::data(index, role);
+        }
+        switch (role) {
+        case Qt::DisplayRole:
+            return mName;
+        case Qt::DecorationRole:
+            return mIcon;
+        case Qt::ToolTipRole:
+            return mUrl.pathOrUrl();
+        default:
+            return QSortFilterProxyModel::data(index, role);
+        }
+    }
+
+private:
+    KUrl mUrl;
+    KIcon mIcon;
+    QString mName;
+};
+
+void ThumbnailPage::setupSrcUrlTreeView()
+{
+    if (d->mSrcUrlTreeView->model()) {
+        // Already initialized
         return;
     }
+    KDirModel* dirModel = new KDirModel(this);
+    dirModel->dirLister()->setDirOnlyMode(true);
+    dirModel->dirLister()->openUrl(d->mSrcBaseUrl.upUrl());
 
-    KDirModel* model = new KDirModel(this);
-    model->dirLister()->setDirOnlyMode(true);
-    model->dirLister()->openUrl(d->mSrcBaseUrl);
+    OnlyBaseUrlProxyModel* onlyBaseUrlModel = new OnlyBaseUrlProxyModel(d->mSrcBaseUrl, d->mSrcBaseIcon, d->mSrcBaseName, this);
+    onlyBaseUrlModel->setSourceModel(dirModel);
 
-    QSortFilterProxyModel *sortModel = new QSortFilterProxyModel(this);
+    QSortFilterProxyModel* sortModel = new QSortFilterProxyModel(this);
     sortModel->setDynamicSortFilter(true);
-    sortModel->setSourceModel(model);
+    sortModel->setSourceModel(onlyBaseUrlModel);
     sortModel->sort(0);
 
-    QTreeView* view = new QTreeView;
-    view->resize(200, 300);
-    view->setEditTriggers(QTreeView::NoEditTriggers);
-    view->setModel(sortModel);
-    for(int i = 1; i < model->columnCount(); ++i) {
-        view->hideColumn(i);
+    d->mSrcUrlModelProxyMapper = new KModelIndexProxyMapper(dirModel, sortModel, this);
+
+    d->mSrcUrlTreeView->setModel(sortModel);
+    for(int i = 1; i < dirModel->columnCount(); ++i) {
+        d->mSrcUrlTreeView->hideColumn(i);
     }
-    view->setHeaderHidden(true);
-    connect(view, SIGNAL(activated(QModelIndex)), SLOT(openUrlFromIndex(QModelIndex)));
-    connect(view, SIGNAL(clicked(QModelIndex)), SLOT(openUrlFromIndex(QModelIndex)));
+    connect(d->mSrcUrlTreeView, SIGNAL(activated(QModelIndex)), SLOT(openUrlFromIndex(QModelIndex)));
+    connect(d->mSrcUrlTreeView, SIGNAL(clicked(QModelIndex)), SLOT(openUrlFromIndex(QModelIndex)));
 
-    QWidgetAction* viewAction = new QWidgetAction(d->mSrcUrlMenu);
-    viewAction->setDefaultWidget(view);
+    dirModel->expandToUrl(d->mSrcUrl);
+    connect(dirModel, SIGNAL(expand(QModelIndex)), SLOT(slotSrcUrlModelExpand(QModelIndex)));
+}
 
-    d->mSrcUrlMenu->addAction(viewAction);
+void ThumbnailPage::slotSrcUrlModelExpand(const QModelIndex& index)
+{
+    QModelIndex viewIndex = d->mSrcUrlModelProxyMapper->mapLeftToRight(index);
+    d->mSrcUrlTreeView->expand(viewIndex);
+    KFileItem item = itemForIndex(index);
+    if (item.url() == d->mSrcUrl) {
+        d->mSrcUrlTreeView->selectionModel()->select(viewIndex, QItemSelectionModel::ClearAndSelect);
+    }
+}
+
+void ThumbnailPage::toggleSrcUrlTreeView()
+{
+    d->mSrcUrlTreeView->setVisible(!d->mSrcUrlTreeView->isVisible());
+    QLayout* layout = d->mSrcUrlTreeView->parentWidget()->layout();
+    layout->setSpacing(d->mSrcUrlTreeView->isVisible() ? KDialog::spacingHint() : 0);
 }
 
 void ThumbnailPage::openUrlFromIndex(const QModelIndex& index)
