@@ -63,7 +63,9 @@ struct DocumentPrivate
     ImageMetaInfoModel mImageMetaInfoModel;
     QUndoStack mUndoStack;
     QString mErrorString;
+#ifdef LCMS2_FOUND
     Cms::Profile::Ptr mCmsProfile;
+#endif
     /** @} */
 
     void scheduleImageLoading(int invertedZoom)
@@ -112,7 +114,9 @@ void Document::reload()
     d->mImageMetaInfoModel.setUrl(d->mUrl);
     d->mUndoStack.clear();
     d->mErrorString.clear();
+#ifdef LCMS2_FOUND
     d->mCmsProfile = 0;
+#endif
 
     switchToImpl(new LoadingDocumentImpl(this));
 }
@@ -490,6 +494,7 @@ QSvgRenderer* Document::svgRenderer() const
     return d->mImpl->svgRenderer();
 }
 
+#ifdef LCMS2_FOUND
 void Document::setCmsProfile(Cms::Profile::Ptr ptr)
 {
     d->mCmsProfile = ptr;
@@ -499,5 +504,6 @@ Cms::Profile::Ptr Document::cmsProfile() const
 {
     return d->mCmsProfile;
 }
+#endif
 
 } // namespace
