@@ -45,8 +45,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <KUrl>
 
 // Local
+#include "config-gwenview.h"
 #include "animateddocumentloadedimpl.h"
+#ifdef LCMS2_FOUND
 #include "cms/cmsprofile.h"
+#endif
 #include "document.h"
 #include "documentloadedimpl.h"
 #include "emptydocumentimpl.h"
@@ -97,7 +100,9 @@ struct LoadingDocumentImplPrivate
     Exiv2::Image::AutoPtr mExiv2Image;
     std::auto_ptr<JpegContent> mJpegContent;
     QImage mImage;
+#ifdef LCMS2_FOUND
     Cms::Profile::Ptr mCmsProfile;
+#endif
 
     /**
      * Determine kind of document and switch to an implementation if it is not
@@ -217,15 +222,19 @@ struct LoadingDocumentImplPrivate
             // image has been rotated
             mImageSize = mJpegContent->size();
 
+#ifdef LCMS2_FOUND
             mCmsProfile = Cms::Profile::loadFromExiv2Image(mExiv2Image.get());
+#endif
         } else {
             mImageSize = reader.size();
         }
         LOG("mImageSize" << mImageSize);
 
+#ifdef LCMS2_FOUND
         if (!mCmsProfile) {
             mCmsProfile = Cms::Profile::loadFromImageData(mData, mFormat);
         }
+#endif
 
         return true;
     }
@@ -430,7 +439,9 @@ void LoadingDocumentImpl::slotMetaInfoLoaded()
     setDocumentFormat(d->mFormat);
     setDocumentImageSize(d->mImageSize);
     setDocumentExiv2Image(d->mExiv2Image);
+#ifdef LCMS2_FOUND
     setDocumentCmsProfile(d->mCmsProfile);
+#endif
 
     d->mMetaInfoLoaded = true;
     emit metaInfoLoaded();
